@@ -22,10 +22,6 @@
 
 #include "ar-card.h"
 
-#ifdef HAVE_CLUTTER
-#include <clutter/clutter.h>
-#endif
-
 G_BEGIN_DECLS
 
 /* A slot */
