@@ -408,8 +408,7 @@ ar_card_theme_pysol_class_foreach_theme_dir (ArCardThemeClass *klass,
   if (!_ar_card_theme_class_foreach_env (klass, "AR_CARD_THEME_PATH_PYSOL", callback, data))
     return FALSE;
 
-  /* FIXMEchpe: is this univeral or ubuntu specific? */
-  return callback (klass, "/usr/share/games/pysol", data);
+  return callback (klass, PYSOL_CARD_THEME_PATH, data);
 }
 
 static void
